OC.L10N.register(
    "files_trashbin",
    {
    "Couldn't delete %s permanently" : "%s را نمی توان برای همیشه حذف کرد",
    "Couldn't restore %s" : "%s را نمی توان بازگرداند",
    "Deleted files" : "فایل های حذف شده",
    "Restore" : "بازیابی",
    "Delete" : "حذف",
    "Delete permanently" : "حذف قطعی",
    "Error" : "خطا",
    "This operation is forbidden" : "این عملیات غیرمجاز است",
    "This directory is unavailable, please check the logs or contact the administrator" : "پوشه‌ در دسترس نیست، لطفا لاگ‌ها را بررسی کنید یا به مدیر سیستم اطلاع دهید",
    "restored" : "بازیابی شد",
    "No entries found in this folder" : "هیچ ورودی‌ای در این پوشه وجود ندارد",
    "Select all" : "انتخاب همه",
    "Name" : "نام",
    "Deleted" : "حذف شده"
},
"nplurals=1; plural=0;");
